"""""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """''
======================================================================
                    Listas de Entidades BSMP
        A posição da entidade na lista corresponde ao seu ID BSMP
======================================================================
""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" ""

list_ps_models = [
    "Empty",
    "FBP",
    "FBP_DCLink",
    "FAC_ACDC",
    "FAC_DCDC",
    "FAC_2S_ACDC",
    "FAC_2S_DCDC",
    "FAC_2P4S_ACDC",
    "FAC_2P4S_DCDC",
    "FAP",
    "FAP_4P",
    "FAC_DCDC_EMA",
    "FAP_2P2S",
    "FAP_IMAS",
    "FAC_2P_ACDC_IMAS",
    "FAC_2P_DCDC_IMAS",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Invalid",
    "Uninitialized",
]

list_common_vars = [
    "ps_status",
    "ps_setpoint",
    "ps_reference",
    "firmware_version",
    "counter_set_slowref",
    "counter_sync_pulse",
    "siggen_enable",
    "siggen_type",
    "siggen_num_cycles",
    "siggen_n",
    "siggen_freq",
    "siggen_amplitude",
    "siggen_offset",
    "siggen_aux_param",
    "wfmref_selected",
    "wfmref_sync_mode",
    "wfmref_gain",
    "wfmref_offset",
    "p_wfmref_start",
    "p_wfmref_end",
    "p_wfmref_idx",
]

# list_curv = ['wfmref','buf_samples_ctom','buf_samples_mtoc']
list_curv = ["wfmref_data_0", "wfmref_data_1", "buf_samples_ctom"]

list_func = [
    "turn_on",
    "turn_off",
    "open_loop",
    "closed_loop",
    "select_op_mode",
    "reset_interlocks",
    "set_command_interface",
    "set_serial_termination",
    "unlock_udc",
    "lock_udc",
    "cfg_source_scope",
    "cfg_freq_scope",
    "cfg_duration_scope",
    "enable_scope",
    "disable_scope",
    "sync_pulse",
    "set_slowref",
    "set_slowref_fbp",
    "set_slowref_readback_mon",
    "set_slowref_fbp_readback_mon",
    "set_slowref_readback_ref",
    "set_slowref_fbp_readback_ref",
    "reset_counters",
    "cfg_wfmref",
    "select_wfmref",
    "get_wfmref_size",
    "reset_wfmref",
    "cfg_siggen",
    "set_siggen",
    "enable_siggen",
    "disable_siggen",
    "set_param",
    "get_param",
    "save_param_eeprom",
    "load_param_eeprom",
    "save_param_bank",
    "load_param_bank",
    "set_dsp_coeffs",
    "get_dsp_coeff",
    "save_dsp_coeffs_eeprom",
    "load_dsp_coeffs_eeprom",
    "save_dsp_modules_eeprom",
    "load_dsp_modules_eeprom",
    "reset_udc",
]

list_op_mode = [
    "Off",
    "Interlock",
    "Initializing",
    "SlowRef",
    "SlowRefSync",
    "Cycle",
    "RmpWfm",
    "MigWfm",
    "FastRef",
]

list_sig_gen_types = [
    "Sine",
    "DampedSine",
    "Trapezoidal",
    "DampedSquaredSine",
    "Square",
]

list_parameters = [
    "PS_Name",
    "PS_Model",
    "Num_PS_Modules",
    "Command_Interface",
    "RS485_Baudrate",
    "RS485_Address",
    "RS485_Termination",
    "UDCNet_Address",
    "Ethernet_IP",
    "Ethernet_Subnet_Mask",
    "Buzzer_Volume",
    "Freq_ISR_Controller",
    "Freq_TimeSlicer",
    "Control_Loop_State",
    "Max_Ref",
    "Min_Ref",
    "Max_Ref_OpenLoop",
    "Min_Ref_OpenLoop",
    "PWM_Freq",
    "PWM_DeadTime",
    "PWM_Max_Duty",
    "PWM_Min_Duty",
    "PWM_Max_Duty_OpenLoop",
    "PWM_Min_Duty_OpenLoop",
    "PWM_Lim_Duty_Share",
    "HRADC_Num_Boards",
    "HRADC_Freq_SPICLK",
    "HRADC_Freq_Sampling",
    "HRADC_Enable_Heater",
    "HRADC_Enable_Monitor",
    "HRADC_Type_Transducer",
    "HRADC_Gain_Transducer",
    "HRADC_Offset_Transducer",
    "SigGen_Type",
    "SigGen_Num_Cycles",
    "SigGen_Freq",
    "SigGen_Amplitude",
    "SigGen_Offset",
    "SigGen_Aux_Param",
    "WfmRef_ID_WfmRef",
    "WfmRef_SyncMode",
    "WfmRef_Frequency",
    "WfmRef_Gain",
    "WfmRef_Offset",
    "Analog_Var_Max",
    "Analog_Var_Min",
    "Hard_Interlocks_Debounce_Time",
    "Hard_Interlocks_Reset_Time",
    "Soft_Interlocks_Debounce_Time",
    "Soft_Interlocks_Reset_Time",
    "Scope_Sampling_Frequency",
    "Scope_Source",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Password",
    "Enable_Onboard_EEPROM",
]



"""BSMP PS."""

from siriuspy.pwrsupply.bsmp.constants import ConstPSBSMP as _ConstPSBSMP


class BasePSAckError(Exception):
    """Exception raised when the ack response is not the expected"""

    def __init__(self, message, *args: object) -> None:
        super().__init__(*args)


class FunctionExecutionPSAckError(BasePSAckError):
    """."""


class InvalidCommandPSAckError(BasePSAckError):
    """."""


class DSPBusyPSAckError(BasePSAckError):
    """."""


class DSPTimeoutPSAckError(BasePSAckError):
    """."""


class ResourceBusyPSAckError(BasePSAckError):
    """."""


class UDCLockedPSAckError(BasePSAckError):
    """."""


class PSInterlockPSAckError(BasePSAckError):
    """."""


# def check_return_code(code: int):
#    """Check return code and raise the corresponding exception"""
#
#   if code == _ConstPSBSMP.ACK_INVALID_CMD:
#       raise InvalidCommandPSAckError()
#   elif code == _ConstPSBSMP.ACK_DSP_BUSY:
#       raise DSPBusyPSAckError()
#   elif code == _ConstPSBSMP.ACK_RESOURCE_BUSY:
#       raise ResourceBusyPSAckError()



"""""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """''
======================================================================
                    Listas de Entidades BSMP
        A posição da entidade na lista corresponde ao seu ID BSMP
======================================================================
""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" ""

# FAC ACDC
list_fac_acdc_soft_interlocks = []

list_fac_acdc_hard_interlocks = [
    "CapBank Overvoltage",
    "Rectifier Overvoltage",
    "Rectifier Undervoltage",
    "Rectifier Overcurrent",
    "Welded Contactor Fault",
    "Opened Contactor Fault",
    "IIB Input Stage Interlock",
    "IIB Command Interlock",
]

list_fac_acdc_iib_is_interlocks = [
    "Rectifier Overvoltage",
    "Input Overcurrent",
    "IGBT Overtemperature",
    "IGBT Overtemperature HW",
    "Driver Overvoltage",
    "Driver Overcurrent",
    "Top Driver Error",
    "Bottom Driver Error",
    "Inductors Overtemperature",
    "Heat-Sink Overtemperature",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

list_fac_acdc_iib_is_alarms = [
    "Rectifier Overvoltage",
    "Input Overcurrent",
    "IGBT Overtemperature",
    "Driver Overvoltage",
    "Driver Overcurrent",
    "Inductors Overtemperature",
    "Heat-Sink Overtemperature",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

list_fac_acdc_iib_cmd_interlocks = [
    "Capbank Overvoltage",
    "Output Overvoltage",
    "External Boards Overvoltage",
    "Auxiliary Board Overcurrent",
    "IDB Board Overcurrent",
    "Rectifier Inductor Overtemperature",
    "Rectifier Heat-Sink Overtemperature",
    "AC Mains Overcurrent",
    "Emergency Button",
    "AC Mains Undervoltage",
    "AC Mains Overvoltage",
    "Ground Leakage Overcurrent",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

list_fac_acdc_iib_cmd_alarms = [
    "Capbank Overvoltage",
    "Output Overvoltage",
    "External Boards Overvoltage",
    "Auxiliary Board Overcurrent",
    "IDB Board Overcurrent",
    "Rectifier Inductor Overtemperature",
    "Rectifier Heat-Sink Overtemperature",
    "Ground Leakage Overcurrent",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

# FAC DCDC
list_fac_dcdc_soft_interlocks = [
    "DCCT 1 Fault",
    "DCCT 2 Fault",
    "DCCT High Difference",
    "Load Feedback 1 Fault",
    "Load Feedback 2 Fault",
]

list_fac_dcdc_hard_interlocks = [
    "Load Overcurrent",
    "CapBank Overvoltage",
    "CapBank Undervoltage",
    "IIB Interlock",
    "External Interlock",
    "Rack Interlock",
]

list_fac_dcdc_iib_interlocks = [
    "Input Overvoltage",
    "Input Overcurrent",
    "Output Overcurrent",
    "IGBT 1 Overtemperature",
    "IGBT 1 Overtemperature HW",
    "IGBT 2 Overtemperature",
    "IGBT 2 Overtemperature HW",
    "Driver Overvoltage",
    "Driver 1 Overcurrent",
    "Driver 2 Overcurrent",
    "Top Driver 1 Error",
    "Bottom Driver 1 Error",
    "Top Driver 2 Error",
    "Bottom Driver 2 Error",
    "Inductors Overtemperature",
    "Heat-Sink Overtemperature",
    "Ground Leakage Overcurrent",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

list_fac_dcdc_iib_alarms = [
    "Input Overvoltage",
    "Input Overcurrent",
    "Output Overcurrent",
    "IGBT 1 Overtemperature",
    "IGBT 2 Overtemperature",
    "Driver Overvoltage",
    "Driver 1 Overcurrent",
    "Driver 2 Overcurrent",
    "Inductors Overtemperature",
    "Heat-Sink Overtemperature",
    "Ground Leakage Overcurrent",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

# FAC-2S AC/DC
list_fac_2s_acdc_soft_interlocks = []
list_fac_2s_acdc_hard_interlocks = [
    "CapBank Overvoltage",
    "Rectifier Overvoltage",
    "Rectifier Undervoltage",
    "Rectifier Overcurrent",
    "Welded Contactor Fault",
    "Opened Contactor Fault",
    "IIB Input Stage Interlock",
    "IIB Command Interlock",
]

list_fac_2s_acdc_iib_is_interlocks = list_fac_acdc_iib_is_interlocks
list_fac_2s_acdc_iib_cmd_interlocks = list_fac_acdc_iib_cmd_interlocks
list_fac_2s_acdc_iib_is_alarms = list_fac_acdc_iib_is_alarms
list_fac_2s_acdc_iib_cmd_alarms = list_fac_acdc_iib_cmd_alarms

# FAC-2S DC/DC
list_fac_2s_dcdc_soft_interlocks = [
    "DCCT 1 Fault",
    "DCCT 2 Fault",
    "DCCT High Difference",
    "Load Feedback 1 Fault",
    "Load Feedback 2 Fault",
]

list_fac_2s_dcdc_hard_interlocks = [
    "Load Overcurrent",
    "Module 1 CapBank Overvoltage",
    "Module 2 CapBank Overvoltage",
    "Module 1 CapBank Undervoltage",
    "Module 2 CapBank Undervoltage",
    "IIB Mod 1 Itlk",
    "IIB Mod 2 Itlk",
    "External Interlock",
    "Rack Interlock",
]

list_fac_2s_dcdc_iib_interlocks = list_fac_dcdc_iib_interlocks
list_fac_2s_dcdc_iib_alarms = list_fac_dcdc_iib_alarms

# FAC-2P4S AC/DC
list_fac_2p4s_acdc_hard_interlocks = [
    "CapBank Overvoltage",
    "Rectifier Overvoltage",
    "Rectifier Undervoltage",
    "Rectifier Overcurrent",
    "Welded Contactor Fault",
    "Opened Contactor Fault",
    "IIB Input Stage Interlock",
    "IIB Command Interlock",
]

list_fac_2p4s_acdc_iib_is_interlocks = list_fac_acdc_iib_is_interlocks
list_fac_2p4s_acdc_iib_cmd_interlocks = list_fac_acdc_iib_cmd_interlocks
list_fac_2p4s_acdc_iib_is_alarms = list_fac_acdc_iib_is_alarms
list_fac_2p4s_acdc_iib_cmd_alarms = list_fac_acdc_iib_cmd_alarms

# FAC-2P4S DC/DC
list_fac_2p4s_dcdc_soft_interlocks = [
    "DCCT 1 Fault",
    "DCCT 2 Fault",
    "DCCT High Difference",
    "Load Feedback 1 Fault",
    "Load Feedback 2 Fault",
    "Arm 1 Overcurrent",
    "Arm 2 Overcurrent",
    "Arms High Difference",
    "Complementary PS Interlock",
]

list_fac_2p4s_dcdc_hard_interlocks = [
    "Load Overcurrent",
    "Module 1 CapBank Overvoltage",
    "Module 2 CapBank Overvoltage",
    "Module 3 CapBank Overvoltage",
    "Module 4 CapBank Overvoltage",
    "Module 5 CapBank Overvoltage",
    "Module 6 CapBank Overvoltage",
    "Module 7 CapBank Overvoltage",
    "Module 8 CapBank Overvoltage",
    "Module 1 CapBank Undervoltage",
    "Module 2 CapBank Undervoltage",
    "Module 3 CapBank Undervoltage",
    "Module 4 CapBank Undervoltage",
    "Module 5 CapBank Undervoltage",
    "Module 6 CapBank Undervoltage",
    "Module 7 CapBank Undervoltage",
    "Module 8 CapBank Undervoltage",
    "IIB 1 Itlk",
    "IIB 2 Itlk",
    "IIB 3 Itlk",
    "IIB 4 Itlk",
    "IIB 5 Itlk",
    "IIB 6 Itlk",
    "IIB 7 Itlk",
    "IIB 8 Itlk",
]

list_fac_2p4s_dcdc_iib_interlocks = list_fac_dcdc_iib_interlocks
list_fac_2p4s_dcdc_iib_alarms = list_fac_dcdc_iib_alarms

# FAC DCDC EMA
list_fac_dcdc_ema_soft_interlocks = ["DCCT Fault", "Load Feedback Fault"]

list_fac_dcdc_ema_hard_interlocks = [
    "Load Overcurrent",
    "DCLink Overvoltage",
    "DCLink Undervoltage",
    "Emergency Button",
    "Load Waterflow",
    "Load Overtemperature",
    "IIB Itlk",
]

list_fac_dcdc_ema_iib_interlocks = [
    "Input Overvoltage",
    "Input Overcurrent",
    "Output Overcurrent",
    "IGBT 1 Overtemperature",
    "IGBT 1 Overtemperature HW",
    "IGBT 2 Overtemperature",
    "IGBT 2 Overtemperature HW",
    "Driver Overvoltage",
    "Driver 1 Overcurrent",
    "Driver 2 Overcurrent",
    "Top Driver 1 Error",
    "Bottom Driver 1 Error",
    "Top Driver 2 Error",
    "Bottom Driver 2 Error",
    "Inductors Overtemperature",
    "Heat-Sink Overtemperature",
    "Ground Leakage Overcurrent",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

list_fac_dcdc_ema_iib_alarms = [
    "Input Overvoltage",
    "Input Overcurrent",
    "Output Overcurrent",
    "IGBT 1 Overtemperature",
    "IGBT 2 Overtemperature",
    "Driver Overvoltage",
    "Driver 1 Overcurrent",
    "Driver 2 Overcurrent",
    "Inductors Overtemperature",
    "Heat-Sink Overtemperature",
    "Ground Leakage Overcurrent",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

# FAC-2P ACDC
list_fac_2p_acdc_imas_soft_interlocks = []

list_fac_2p_acdc_imas_hard_interlocks = [
    "CapBank Overvoltage",
    "Rectifier Overcurrent",
    "AC Mains Contactor Fault",
    "Module A Interlock",
    "Module B Interlock",
    "DCDC Interlock",
]

# FAC-2P DCDC
list_fac_2p_dcdc_imas_soft_interlocks = []

list_fac_2p_dcdc_imas_hard_interlocks = [
    "Load Overcurrent",
    "Module 1 CapBank_Overvoltage",
    "Module 2 CapBank_Overvoltage",
    "Module 1 CapBank_Undervoltage",
    "Module 2 CapBank_Undervoltage",
    "Arm 1 Overcurrent",
    "Arm 2 Overcurrent",
    "Arms High_Difference",
    "ACDC Interlock",
]



from siriuspy.bsmp.serial import IOInterface as _IOInterface
from siriuspy.pwrsupply.bsmp.commands import PSBSMP as _PSBSMP

from .entities import EntitiesPS as _EntitiesPS


class CommonPSBSMP(_PSBSMP):
    """Essa classe espera receber como parâmetro um objeto do tipo siriuspy.bsmp.Entities,
    que possui a relação entre endereço e tipo de entidade bsmp que o dispositivo
    que desejamos controlar possui.
    Caso esse objeto seja nulo, diversas funções deverão ser implementadas novamente.
    ver from siriuspy.pwrsupply.bsmp.entities import EntitiesPS"""

    _timeout_read_variable: float = 100  # [ms]
    _timeout_execute_function: float = 100  # [ms]
    _timeout_remove_vars_groups: float = 100  # [ms]
    _timeout_create_vars_groups: float = 100  # [ms]
    _timeout_read_group_of_variables: float = 100  # [ms]
    _timeout_request_curve_block: float = 100  # [ms]
    _timeout_curve_block: float = 100  # [ms]
    _timeout_query_list_of_group_of_variables: float = 100  # [ms]
    _timeout_query_group_of_variables: float = 100  # [ms]

    _sleep_turn_onoff = 0.050  # [s]
    _sleep_reset_udc = 1.000  # [s]
    _sleep_disable_scope = 0.5  # [s]
    _sleep_select_op_mode = 0.030  # [s]

    def __init__(
        self, iointerface: _IOInterface, slave_address: int, entities: _EntitiesPS
    ):
        super().__init__(iointerface, slave_address, entities)
        self._entities: _EntitiesPS

    @property
    def entities(self) -> _EntitiesPS:
        """Return BSMP entities."""
        return self._entities



from siriuspy.bsmp import IOInterface as _IOInterface
from siriuspy.pwrsupply.bsmp.constants import ConstPSBSMP as _ConstPSBSMP

from .command import CommonPSBSMP as _CommonPSBSMP
from .entities import EntitiesPS as _EntitiesPS


class GenericPowerPS:
    def __init__(self, iointerf: _IOInterface, address: int) -> None:
        self._bsmp: _CommonPSBSMP = _CommonPSBSMP(
            iointerface=iointerf, entities=_EntitiesPS(), slave_address=address
        )

    def turn_on(self):
        ack, data = self._bsmp.execute_function(
            func_id=_ConstPSBSMP.F_TURN_ON,
            input_val=(),
        )
        return ack, data



"""""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """''
======================================================================
                    Listas de Entidades BSMP
        A posição da entidade na lista corresponde ao seu ID BSMP
======================================================================
""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" """""" ""

# FBP
list_fbp_soft_interlocks = ["Heat-Sink Overtemperature"]

list_fbp_hard_interlocks = [
    "Load Overcurrent",
    "Load Overvoltage",
    "DCLink Overvoltage",
    "DCLink Undervoltage",
    "DCLink Relay Fault",
    "DCLink Fuse Fault",
    "MOSFETs Driver Fault",
    "Welded Relay Fault",
]

# FBP DC-Link
list_fbp_dclink_hard_interlocks = [
    "Power_Module_1_Fault",
    "Power_Module_2_Fault",
    "Power_Module_3_Fault",
    "Total_Output_Overvoltage",
    "Power_Module_1_Overvoltage",
    "Power_Module_2_Overvoltage",
    "Power_Module_3_Overvoltage",
    "Total_Output_Undervoltage",
    "Power_Module_1_Undervoltage",
    "Power_Module_2_Undervoltage",
    "Power_Module_3_Undervoltage",
    "Smoke_Detector",
    "External_Interlock",
]



#!/usr/bin/env python3
import pkg_resources

from setuptools import find_packages, setup

from src.pydrs import __author__, __version__


def get_abs_path(relative):
    return pkg_resources.resource_filename(__name__, relative)


def get_long_description() -> str:
    desc = ""
    with open(get_abs_path("README.md"), "r") as _f:
        desc += _f.read().strip()

    desc += "\n\n"

    with open(get_abs_path("CHANGES.md"), "r") as _f:
        desc += _f.read().strip()

    return desc


long_description = get_long_description()


with open(get_abs_path("requirements.txt"), "r") as _f:
    _requirements = _f.read().strip().split("\n")

setup(
    author=__author__,
    classifiers=[
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3",
        "Topic :: Scientific/Engineering",
        "Operating System :: OS Independent",
    ],
    description="",
    download_url="https://github.com/lnls-sirius/pydrs",
    include_package_data=True,
    install_requires=_requirements,
    license="MIT License",
    long_description=long_description,
    long_description_content_type="text/markdown",
    name="pydrs",
    url="https://github.com/lnls-sirius/pydrs",
    version=__version__,
    packages=find_packages(
        where="src",
        include=[
            "pydrs*",
        ],
    ),
    package_dir={"": "src"},
    python_requires=">=3.6",
    scripts=["scripts/hradc_scope.py", "scripts/update_hradc.py"],
    zip_safe=False,
)



#import sys
#sys.path.insert(0, '../../')
#from pyELP import *

import pydrs
import matplotlib.pyplot as plt
import matplotlib.animation as anim
import numpy as np
import time
import sys


# Inicializa conexoes
com_port = input("\n Porta serial: ")
baud_rate = int(input("\n Baud-rate: "))
com_add = int(input("\n Endereco serial: "))
fs = float(input("\n Frequencia de amostragem: "))
num_curves = int(input("\n Numero de curvas: "))
id_curve = int(input("\n Indice da curva: "))
id_netsignal = int(input("\n Indice do netsignal: "))
id_analog_var_max = int(input("\n Indice do parametro Analog_Var_Max: "))

size_buf = 4096
n = int(size_buf/num_curves)
rangeFFT = range(int(n/2))
k = np.arange(n)
T = n/fs
frq = k/T 
frq = frq[rangeFFT] # one side frequency range

drs = pydrs.SerialDRS()
drs.Connect(com_port, baud_rate)
drs.SetSlaveAdd(com_add)

# Inicializa plot
fig = plt.figure()
ax1 = fig.add_subplot(2,1,1)
ax2 = fig.add_subplot(2,1,2)

drs.set_param('Analog_Var_Max', id_analog_var_max, id_netsignal)

def animate(i):
    try:
        drs.disable_buf_samples()
        time.sleep(4)
        buffer = np.array(drs.read_buf_samples_ctom())
        drs.enable_buf_samples()
        
        buffer = buffer[id_curve:size_buf:num_curves]
        
        bufferMean = buffer.mean()
        std = buffer.std()
        buffer_max = buffer.max()
        buffer_min = buffer.min()
        buffer_pkpk = buffer_max - buffer_min
        
        Y = np.fft.fft(buffer-bufferMean)/n # fft computing and normalization
        try:
            Y = 20*np.log10(abs(Y[rangeFFT]))
            freq_pk = float(frq[np.where(Y == max(Y))])
        except:
            Y = frq*0
            freq_pk = 0
        
        
        print('\nMean: ' + str(bufferMean))
        print('Std: ' + str(std))
        print('Max: ' + str(buffer_max))
        print('Min: ' + str(buffer_min))
        print('Pk-Pk: ' + str(buffer_pkpk))      
        print('Peak Freq: ' + str(freq_pk))
               
        ax1.clear()
        ax2.clear()

        ax1.ticklabel_format(useOffset = False)
        #ax1.set_ylabel('iMeas [A]')
        ax1.plot(buffer)
        ax1.grid()   
        
        ax2.plot(frq,Y) # plotting the spectrum
        #ax2.set_xlim([0, 600])
        #ax2.set_ylim([0, 0.003])
        ax2.set_xlabel('Freq (Hz)')
        ax2.set_ylabel('|Y(freq)|')
        ax2.grid()

    except Exception as e:
        print(str(e))
        

ani = anim.FuncAnimation(fig, animate, interval = 200)
plt.show()

drs.Disconnect()




from .command import CommonPSBSMP
from .interface import SerialInterface
from .entities import EntitiesPS, Parameter, Parameters

__all__ = ["CommonPSBSMP", "SerialInterface", "EntitiesPS", "Parameter", "Parameters"]
